[![Build Status](https://github.com/dbbs-lab/bsb-hdf5/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb-hdf5/actions/workflows/main.yml)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# bsb-hdf5

`bsb-hdf5` is a plugin of the [BSB](https://github.com/dbbs-lab/bsb). 
It contains the storage engine allowing the user to save and load their models' 
in HDF5 files.
